summaryrefslogtreecommitdiffstats
path: root/src/jogl/classes/javax/media/opengl/GLContext.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/jogl/classes/javax/media/opengl/GLContext.java')
-rw-r--r--src/jogl/classes/javax/media/opengl/GLContext.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/jogl/classes/javax/media/opengl/GLContext.java b/src/jogl/classes/javax/media/opengl/GLContext.java
index 3a72319bb..f4dbde6b2 100644
--- a/src/jogl/classes/javax/media/opengl/GLContext.java
+++ b/src/jogl/classes/javax/media/opengl/GLContext.java
@@ -1010,12 +1010,12 @@ public abstract class GLContext {
}
/**
* Indicates whether this GLContext allows CPU sourced data (indices, vertices ..) as opposed to a GPU buffer source (VBO),
* e.g. {@link GL2#glDrawElements(int, int, int, java.nio.Buffer)}.
* <p>Includes [GL2ES1, GLES2] == [ GL4bc, GL3bc, GL2, GLES1, GL2ES1, GLES2 ].</p>
* <p>See Bug 852 - https://jogamp.org/bugzilla/show_bug.cgi?id=852 </p>
*/
- public final boolean isCPUSourcedAvail() {
+ public final boolean isCPUDataSourcingAvail() {
return isGL2ES1() || isGLES2();
}
@@ -1010,12 +1010,12 @@ public abstract class GLContext {
}
/**
- * Indicates whether this GLContext allows CPU sourced data (indices, vertices ..) as opposed to a GPU buffer source (VBO),
+ * Indicates whether this GLContext allows CPU data sourcing (indices, vertices ..) as opposed to using a GPU buffer source (VBO),
* e.g. {@link GL2#glDrawElements(int, int, int, java.nio.Buffer)}.
* <p>Includes [GL2ES1, GLES2] == [ GL4bc, GL3bc, GL2, GLES1, GL2ES1, GLES2 ].</p>